@@ -44,7 +44,7 @@
 #define CG_BUILD_BASESCOPE 0
 
 #define HDF5_INCLUDE_PATH ""
-#define HDF5_LIBRARY      "/usr/lib/libhdf5.so"
+#define HDF5_LIBRARY      "/usr/lib/libhdf5.so;/usr/lib/libsz.so;/usr/lib/libz.so;/usr/lib/libdl.so;/usr/lib/libm.so"
 
 #define HDF5_NEED_MPI     0
 #define HDF5_NEED_SZIP    0
